@@ -178,9 +178,13 @@ def test_volume_prune(openstack_name, dot_openstack, caplog):
 def test_backup_create_no_names(openstack_name, dot_openstack, caplog):
     o = OpenStack(settings.CONFIG_DIR)
     o.o.volume.create('--size=1', openstack_name)
+    backup_name = f'2020-03-22-{openstack_name}'
+    o.o.volume.create('--size=1', backup_name)
     o.backup_create([])
     available_snapshot = f'AVAILABLE {o.backup_name_create(openstack_name)}'
     assert available_snapshot in caplog.text
+    skipped = f'skipping {backup_name}'
+    assert skipped in caplog.text
 
 
 @pytest.mark.openstack_integration
